@@ -294,7 +294,6 @@ class Graph:
 
 		return eq_H
 
-
 '''
     File name: algorithm.py
     Description: The Hungarian Method for the assignment problem.
@@ -490,9 +489,24 @@ def find_matching(_G, return_type = 'list'):
 				T.add(y)
 
 	if return_type == 'list':
-		return list(map(lambda e: (e.vertices[0] + '-' + e.vertices[1], e.weight), M))
+		return list(map(lambda e: ((e.vertices[0], e.vertices[1]), e.weight), M))
 	elif return_type == 'total':
 		total = 0
 		for e in M:
 			total = total + e.weight
 		return total
+
+ex_L = {
+	'Ann': {'RB': 3, 'CAM': 2, 'GK': 1},
+	'Ben': {'LW': 3, 'S': 2, 'CM': 1},
+	'Cal': {'CAM': 3, 'RW': 2, 'SWP': 1},
+	'Dan': {'S': 3, 'LW': 2, 'GK': 1},
+	'Ela': {'GK': 3, 'LW': 2, 'F': 1},
+	'Fae': {'CM': 3, 'GK': 2, 'CAM': 1},
+	'Gio': {'GK': 3, 'CM': 2, 'S': 1},
+	'Hol': {'CAM': 3, 'F': 2, 'SWP': 1},
+	'Ian': {'S': 3, 'RW': 2, 'RB': 1},
+	'Jon': {'F': 3, 'LW': 2, 'CB': 1},
+	'Kay': {'GK': 3, 'RW': 2, 'LW': 1, 'LB': 0}
+}
+print(find_matching(ex_L))
